# EukCC

EukCC is a tool to predict genome quality in microbial eukaryotes.

A manuscript is in preparation.

## Install and use
Documentation of the tool can be found here:  [https://eukcc.readthedocs.io/en/latest/](https://eukcc.readthedocs.io/en/latest/)
